==> js-0.15.0.tgz: package/src/plugins/auctionHouseModule/operations/loadListing.ts <==
import type { Commitment } from '@safecoin/web3.js';
import type { Metaplex } from '@/Metaplex';
import { useOperation, Operation, OperationHandler, amount } from '@/types';
import { LazyListing, Listing } from '../models/Listing';
import { DisposableScope } from '@/utils';
import { assertNftOrSftWithToken } from '../../nftModule';

// -----------------
// Operation
// -----------------

const Key = 'LoadListingOperation' as const;

/**
 * @group Operations
 * @category Constructors
 */
export const loadListingOperation = useOperation<LoadListingOperation>(Key);

/**
 * @group Operations
 * @category Types
 */
export type LoadListingOperation = Operation<
  typeof Key,
  LoadListingInput,
  Listing
>;

/**
 * @group Operations
 * @category Inputs
 */
export type LoadListingInput = {
  lazyListing: LazyListing;
  loadJsonMetadata?: boolean; // Default: true

  /** The level of commitment desired when querying the blockchain. */
  commitment?: Commitment;
};

/**
 * @group Operations
 * @category Handlers
 */
export const loadListingOperationHandler: OperationHandler<LoadListingOperation> =
  {
    handle: async (
      operation: LoadListingOperation,
      metaplex: Metaplex,
      scope: DisposableScope
    ) => {
      const {
        lazyListing,
        loadJsonMetadata = true,
        commitment,
      } = operation.input;

      const asset = await metaplex
        .nfts()
        .findByMetadata({
          metadata: lazyListing.metadataAddress,
          tokenOwner: lazyListing.sellerAddress,
          commitment,
          loadJsonMetadata,
        })
        .run(scope);
      assertNftOrSftWithToken(asset);

      return {
        ...lazyListing,
        model: 'listing',
        lazy: false,
        asset,
        tokens: amount(lazyListing.tokens, asset.mint.currency),
      };
    },
  };

==> js-0.18.3.tgz: package/src/plugins/auctionHouseModule/operations/loadListing.ts <==
import { assertNftOrSftWithToken } from '../../nftModule';
import { LazyListing, Listing } from '../models/Listing';
import type { Metaplex } from '@/Metaplex';
import {
  amount,
  Operation,
  OperationHandler,
  OperationScope,
  useOperation,
} from '@/types';

// -----------------
// Operation
// -----------------

const Key = 'LoadListingOperation' as const;

/**
 * Transforms a `LazyListing` model into a `Listing` model.
 *
 * ```ts
 * const listing = await metaplex
 *   .auctionHouse()
 *   .loadListing({ lazyListing };
 * ```
 *
 * @group Operations
 * @category Constructors
 */
export const loadListingOperation = useOperation<LoadListingOperation>(Key);

/**
 * @group Operations
 * @category Types
 */
export type LoadListingOperation = Operation<
  typeof Key,
  LoadListingInput,
  Listing
>;

/**
 * @group Operations
 * @category Inputs
 */
export type LoadListingInput = {
  /** The `LazyListing` model to transform into the `Listing`.  */
  lazyListing: LazyListing;

  /**
   * Whether or not we should fetch the JSON Metadata for the NFT or SFT.
   *
   * @defaultValue `true`
   */
  loadJsonMetadata?: boolean;
};

/**
 * @group Operations
 * @category Handlers
 */
export const loadListingOperationHandler: OperationHandler<LoadListingOperation> =
  {
    handle: async (
      operation: LoadListingOperation,
      metaplex: Metaplex,
      scope: OperationScope
    ) => {
      const { lazyListing, loadJsonMetadata = true } = operation.input;
      const asset = await metaplex.nfts().findByMetadata(
        {
          metadata: lazyListing.metadataAddress,
          tokenOwner: lazyListing.sellerAddress,
          loadJsonMetadata,
        },
        scope
      );
      assertNftOrSftWithToken(asset);

      return {
        ...lazyListing,
        model: 'listing',
        lazy: false,
        asset,
        tokens: amount(lazyListing.tokens, asset.mint.currency),
      };
    },
  };
